@@ -5,14 +5,15 @@ import pytest
 
 from datetime import date
 
+
 class TestInvoice(UnitTest):
     def test_create(self):
         generator = InvoiceItemGenerator()
-        
-        customer_id = 123456 
+
+        customer_id = 123456
         recipient_address = "My customer..."
         create_date = "2018-09-17"
-        due_date ="2018-10-16"
+        due_date = "2018-10-16"
         service_period_from = date(2019, 10, 1)
         service_period_to = date(2019, 10, 31)
         title = "Invoice"
@@ -27,8 +28,29 @@ class TestInvoice(UnitTest):
         cash_discount = 2.5
         cash_discount_days = 5
         project_id = 654321
+        tags = ["Hosting", "Europe"]
 
-        response = self.moco.Invoice.create(customer_id, recipient_address, create_date, due_date, service_period_from, service_period_to, title, tax, currency, items, status=status, change_address=change_address, salutation=salutation, footer=footer, discount=discount, cash_discount=cash_discount, cash_discount_days=cash_discount_days, project_id=project_id)
+        response = self.moco.Invoice.create(
+            customer_id,
+            recipient_address,
+            create_date,
+            due_date,
+            service_period_from,
+            service_period_to,
+            title,
+            tax,
+            currency,
+            items,
+            status=status,
+            change_address=change_address,
+            salutation=salutation,
+            footer=footer,
+            discount=discount,
+            cash_discount=cash_discount,
+            cash_discount_days=cash_discount_days,
+            project_id=project_id,
+            tags=tags
+        )
         data = response["data"]
 
         assert data["customer_id"] == customer_id
@@ -51,18 +73,19 @@ class TestInvoice(UnitTest):
         assert data["cash_discount"] == cash_discount
         assert data["cash_discount_days"] == cash_discount_days
         assert data["project_id"] == project_id
+        assert data["tags"] == tags
 
         assert response["method"] == "POST"
 
     def test_create_default_status(self):
         generator = InvoiceItemGenerator()
-        
+
         default_status = 'created'
 
-        customer_id = 123456 
+        customer_id = 123456
         recipient_address = "My customer..."
         created_date = "2018-09-17"
-        due_date ="2018-10-16"
+        due_date = "2018-10-16"
         service_period_from = date(2019, 10, 1)
         service_period_to = date(2019, 10, 31)
         title = "Invoice"
@@ -70,22 +93,21 @@ class TestInvoice(UnitTest):
         currency = "CHF"
         items = [generator.generate_title("this is the title"), generator.generate_separator()]
 
-
-        response = self.moco.Invoice.create(customer_id, recipient_address, created_date, due_date, service_period_from, service_period_to, title, tax, currency, items)
+        response = self.moco.Invoice.create(customer_id, recipient_address, created_date, due_date, service_period_from,
+                                            service_period_to, title, tax, currency, items)
         data = response["data"]
-        
-        assert data["status"] == default_status
 
+        assert data["status"] == default_status
 
     def test_create_default_change_address(self):
         generator = InvoiceItemGenerator()
-        
+
         default_change_address = 'invoice'
 
-        customer_id = 123456 
+        customer_id = 123456
         recipient_address = "My customer..."
         created_date = "2018-09-17"
-        due_date ="2018-10-16"
+        due_date = "2018-10-16"
         service_period_from = date(2019, 10, 1)
         service_period_to = date(2019, 10, 31)
         title = "Invoice"
@@ -93,12 +115,11 @@ class TestInvoice(UnitTest):
         currency = "CHF"
         items = [generator.generate_title("this is the title"), generator.generate_separator()]
 
-
-        response = self.moco.Invoice.create(customer_id, recipient_address, created_date, due_date, service_period_from, service_period_to, title, tax, currency, items)
+        response = self.moco.Invoice.create(customer_id, recipient_address, created_date, due_date, service_period_from,
+                                            service_period_to, title, tax, currency, items)
         data = response["data"]
-        
-        assert data["change_address"] == default_change_address
 
+        assert data["change_address"] == default_change_address
 
     def test_update_status(self):
         invoice_id = 2
@@ -109,7 +130,7 @@ class TestInvoice(UnitTest):
 
         assert data["status"] == status
         assert response["method"] == "PUT"
-    
+
     def test_timesheet(self):
         invoice_id = 2
 
@@ -124,7 +145,6 @@ class TestInvoice(UnitTest):
 
         assert response["method"] == "GET"
 
-
     def test_get(self):
         invoice_id = 2
 
@@ -148,7 +168,6 @@ class TestInvoice(UnitTest):
 
         assert response["method"] == "GET"
 
-
     def test_locked_sort_default(self):
         sort_by = "this is the field to sort by"
 
@@ -184,7 +203,8 @@ class TestInvoice(UnitTest):
         identifier = "INVOICE-001"
         term = "horse"
 
-        response = self.moco.Invoice.getlist(status=status, date_from=date_from, date_to=date_to, tags=tags, identifier=identifier, term=term)
+        response = self.moco.Invoice.getlist(status=status, date_from=date_from, date_to=date_to, tags=tags,
+                                             identifier=identifier, term=term)
         params = response["params"]
 
         assert params["status"] == status
@@ -221,4 +241,3 @@ class TestInvoice(UnitTest):
 
         response = self.moco.Invoice.getlist(page=page_overwrite)
         assert response["params"]["page"] == page_overwrite
-        
\ No newline at end of file
